###################
Directory Structure
###################

Example directory structures for a Terraform module.


*******
Example
*******

.. code-block::

  .
  ├── .terraform-version
  ├── backend-us-east-1.tfvars
  ├── dev-us-east-1.tfvars
  └── main.tf
